==> cppad_2016.00.00.1.orig.tar.gz: cppad-20160000.1/doc/_speed_main_xml.js <==
var list_across0 = [
'_contents_xml.htm',
'_reference.xml',
'_index.xml',
'_search_xml.htm',
'_external.xml'
];
var list_up0 = [
'cppad.xml',
'speed.xml',
'speed_main.xml'
];
var list_down2 = [
'install.xml',
'introduction.xml',
'ad.xml',
'adfun.xml',
'preprocessor.xml',
'multi_thread.xml',
'utility.xml',
'ipopt_solve.xml',
'example.xml',
'speed.xml',
'appendix.xml'
];
var list_down1 = [
'speed_main.xml',
'speed_utility.xml',
'speed_double.xml',
'speed_adolc.xml',
'speed_cppad.xml',
'speed_fadbad.xml',
'speed_sacado.xml'
];
var list_down0 = [
'link_det_lu.xml',
'link_det_minor.xml',
'link_mat_mul.xml',
'link_ode.xml',
'link_poly.xml',
'link_sparse_hessian.xml',
'link_sparse_jacobian.xml',
'microsoft_timer.xml'
];
var list_current0 = [
'speed_main.xml#Syntax',
'speed_main.xml#Purpose',
'speed_main.xml#package',
'speed_main.xml#package.AD Package',
'speed_main.xml#package.double',
'speed_main.xml#package.profile',
'speed_main.xml#test',
'speed_main.xml#test.correct',
'speed_main.xml#test.speed',
'speed_main.xml#seed',
'speed_main.xml#option_list',
'speed_main.xml#option_list.onetape',
'speed_main.xml#option_list.optimize',
'speed_main.xml#option_list.atomic',
'speed_main.xml#option_list.memory',
'speed_main.xml#Sparsity Options',
'speed_main.xml#Sparsity Options.boolsparsity',
'speed_main.xml#Sparsity Options.colpack',
'speed_main.xml#Correctness Results',
'speed_main.xml#Speed Results',
'speed_main.xml#Speed Results.n_sweep',
'speed_main.xml#Link Functions'
];
function choose_across0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_across0[index-1];
}
function choose_up0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_up0[index-1];
}
function choose_down2(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down2[index-1];
}
function choose_down1(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down1[index-1];
}
function choose_down0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down0[index-1];
}
function choose_current0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_current0[index-1];
}

==> cppad_2017.00.00.4.orig.tar.gz: cppad-20170000.4/doc/_speed_main_xml.js <==
var list_across0 = [
'_contents_xml.htm',
'_reference.xml',
'_index.xml',
'_search_xml.htm',
'_external.xml'
];
var list_up0 = [
'cppad.xml',
'speed.xml',
'speed_main.xml'
];
var list_down2 = [
'install.xml',
'introduction.xml',
'ad.xml',
'adfun.xml',
'preprocessor.xml',
'multi_thread.xml',
'utility.xml',
'ipopt_solve.xml',
'example.xml',
'speed.xml',
'appendix.xml'
];
var list_down1 = [
'speed_main.xml',
'speed_utility.xml',
'speed_double.xml',
'speed_adolc.xml',
'speed_cppad.xml',
'speed_fadbad.xml',
'speed_sacado.xml'
];
var list_down0 = [
'link_det_lu.xml',
'link_det_minor.xml',
'link_mat_mul.xml',
'link_ode.xml',
'link_poly.xml',
'link_sparse_hessian.xml',
'link_sparse_jacobian.xml',
'microsoft_timer.xml'
];
var list_current0 = [
'speed_main.xml#Syntax',
'speed_main.xml#Purpose',
'speed_main.xml#package',
'speed_main.xml#package.AD Package',
'speed_main.xml#package.double',
'speed_main.xml#package.profile',
'speed_main.xml#test',
'speed_main.xml#test.correct',
'speed_main.xml#test.speed',
'speed_main.xml#seed',
'speed_main.xml#Global Options',
'speed_main.xml#Global Options.onetape',
'speed_main.xml#Global Options.optimize',
'speed_main.xml#Global Options.atomic',
'speed_main.xml#Global Options.memory',
'speed_main.xml#Sparsity Options',
'speed_main.xml#Sparsity Options.boolsparsity',
'speed_main.xml#Sparsity Options.revsparsity',
'speed_main.xml#Sparsity Options.colpack',
'speed_main.xml#Correctness Results',
'speed_main.xml#Speed Results',
'speed_main.xml#Speed Results.n_sweep',
'speed_main.xml#Link Functions'
];
function choose_across0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_across0[index-1];
}
function choose_up0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_up0[index-1];
}
function choose_down2(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down2[index-1];
}
function choose_down1(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down1[index-1];
}
function choose_down0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down0[index-1];
}
function choose_current0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_current0[index-1];
}
